@@ -13,13 +13,12 @@
 
 #include "kgpgtransaction.h"
 
-#include <KDebug>
-#include <knewpassworddialog.h>
-#include <KLocale>
-
 #include "gpgproc.h"
 #include "kgpginterface.h"
 
+#include <KDebug>
+#include <knewpassworddialog.h>
+#include <KLocale>
 #include <KPushButton>
 #include <QByteArray>
 #include <QStringList>
@@ -62,6 +61,8 @@ public:
 
 	void write(const QByteArray &a);
 
+	static const QStringList &hintNames(void);
+
 private:
 	void processDone();
 
@@ -171,8 +172,37 @@ KGpgTransactionPrivate::slotReadReady()
 			}
 		} else if (line.startsWith(QLatin1String("[GNUPG:] CARDCTRL "))) {
 			// just ignore them, pinentry should handle that
-		} else if (m_parent->nextLine(line)) {
-			sendQuit();
+		} else {
+			// all known hints
+			int i = 0;
+			bool matched = false;
+			foreach (const QString &hintName, hintNames()) {
+				const KGpgTransaction::ts_hintType h = static_cast<KGpgTransaction::ts_hintType>(i++);
+				if (!line.startsWith(hintName))
+					continue;
+
+				matched = true;
+
+				bool r;
+				const int skip = hintName.length();
+				if (line.length() == skip) {
+					r = m_parent->hintLine(h, QString());
+				} else {
+					r = m_parent->hintLine(h, line.mid(skip + 1).trimmed());
+				}
+
+				if (!r) {
+					m_parent->setSuccess(KGpgTransaction::TS_MSG_SEQUENCE);
+					sendQuit();
+				}
+
+				break;
+			}
+
+			if (!matched) {
+				if (m_parent->nextLine(line))
+					sendQuit();
+			}
 		}
 	}
 }
@@ -251,6 +281,19 @@ KGpgTransactionPrivate::write(const QByteArray &a)
 #endif /* KGPG_DEBUG_TRANSACTIONS */
 }
 
+const QStringList &
+KGpgTransactionPrivate::hintNames (void)
+{
+	static QStringList hints;
+
+	if (hints.isEmpty()) {
+		hints.insert(KGpgTransaction::HT_KEYEXPIRED, QLatin1String("[GNUPG:] KEYEXPIRED"));
+		hints.insert(KGpgTransaction::HT_SIGEXPIRED, QLatin1String("[GNUPG:] SIGEXPIRED"));
+	}
+
+	return hints;
+}
+
 void
 KGpgTransactionPrivate::processDone()
 {
@@ -307,7 +350,7 @@ KGpgTransaction::askNewPassphrase(const QString& text)
 	d->m_passwordDialog->setAllowEmptyPasswords(false);
 	connect(d->m_passwordDialog, SIGNAL(newPassword(QString)), SLOT(slotPasswordEntered(QString)));
 	connect(d->m_passwordDialog, SIGNAL(rejected()), SLOT(slotPasswordAborted()));
-	connect(d->m_process, SIGNAL(processExited()), d->m_passwordDialog->button(KDialog::Cancel), SLOT(clicked()));
+	connect(d->m_process, SIGNAL(processExited()), d->m_passwordDialog->button(KDialog::Cancel), SLOT(click()));
 	d->m_passwordDialog->show();
 }
 
@@ -334,6 +377,17 @@ KGpgTransaction::boolQuestion(const QString& line)
 	return BA_UNKNOWN;
 }
 
+bool
+KGpgTransaction::hintLine(const ts_hintType hint, const QString &args)
+{
+	switch (hint) {
+	case HT_KEYEXPIRED:
+		return !args.isEmpty();
+	default:
+		return true;
+	}
+}
+
 void
 KGpgTransaction::finish()
 {
@@ -494,7 +548,7 @@ KGpgTransaction::askPassphrase(const QString &message)
 	--d->m_tries;
 
 	emit statusMessage(i18n("Requesting Passphrase"));
-	return (KgpgInterface::sendPassphrase(passdlgmessage, d->m_process, false, qobject_cast<QWidget *>(parent())) == 0);
+	return (KgpgInterface::sendPassphrase(passdlgmessage, d->m_process, qobject_cast<QWidget *>(parent())) == 0);
 }
 
 void
